module ContainersCp::Assets
  module ResourceHelper
    K = 1000.0
    K_BINARY = 1024.0

    # Convert number of bytes to gigabytes to store in the DB.
    def parse_memory_gb(memory_str)
      memory_bytes = parse_resource(memory_str)
      memory_bytes.nil? ? nil : memory_bytes / K_BINARY**3
    end

    # Parse the resource string and convert to its base unit.
    def parse_resource(resource_str)
      multiplier = K

      return nil if resource_str.blank?

      suffixes = %w[E P T G M K]
      # Use binary multiplier if binary unit given.
      if (resource_str.end_with? "i") && suffixes.include?(resource_str[-2])
        multiplier = K_BINARY
        resource_str = resource_str[0..-2]
      end

      suffix = resource_str[-1]

      if !numeric?(suffix)
        out = resource_str[0..-2].to_f
        # Not supporting larger units due to DB constraints.
        case suffix
        when "T"
          out *= multiplier**4.0
        when "G"
          out *= multiplier**3.0
        when "M"
          out *= multiplier**2.0
        when "K", "k"
          out *= multiplier
        when "m"
          out /= multiplier
        else
          tags = %W[suffix:#{suffix} asset_type:kubernetes_node]
          statsd.increment("unsupported_resource_suffix", tags: tags)

          logger.warn "Unsupported suffix: #{suffix} for resource #{resource_str}"
          return nil
        end
      else
        # Sometimes there will not be a unit given,
        # so assume it is the base unit.
        out = resource_str.to_f
      end

      out
    end

    def numeric?(str)
      begin
        is_numeric = !Float(str).nil?
      rescue
        is_numeric = false
      end
      is_numeric
    end
  end
end
