# frozen_string_literal: true

require "containers_cp/constants"
require "containers_cp/assets/helpers/resource_helper"

module ContainersCp::Assets
  module Containers
    module Namespaces
      ASSET_NAME = "namespaces"

      class Processor < ::ContainersCp::Processing::AssetProcessor
        include ::ContainersCp::Assets::ResourceHelper

        register source: DATA_SOURCE_K8S_AGENT, service: ASSET_SERVICE, asset: ASSET_NAME, format: FORMAT_JSON

        model ::KubernetesNamespace

        asset_identifiers(:name, :containers_cluster_id)

        copy_attributes_from_dso %w[kubernetes_assigned_uid kubernetes_cluster_name]

        set_callback :process_assets, :before, :clean_data

        def clean_data
          data.each do |dso|
            dso[:name] = dso[:metadata][:name]
            dso[:kubernetes_assigned_uid] = dso[:metadata][:uid]
            dso[:kubernetes_cluster_name] = @cluster_name
            dso[:containers_cluster_id] = @parent_cluster.id
          end
        end

        def process_asset(namespace, dso)
          namespace_metadata = dso[:metadata]

          # Populate account info
          if @parent_cluster.has_owner_account
            update_asset_account_info(namespace)
          else
            logger.debug "No account info found on cluster: #{@cluster_name}, ID: #{@parent_cluster.id}"
            wavefront.counter("containers_cp.namespaces.no_account_info", 1, cluster: @cluster_name)
          end

          # Add Labels and Annotations
          process_labels_and_annotations(namespace, namespace_metadata)

          count_changed_assets(namespace)
        end
      end
    end
  end
end

if Application.resolve("runtime").sandbox?
  def generate_namespace_job(customer_id)
    generate_job customer_id, "namespaces"
  end

  def process_namespaces(customer_id)
    process_payload ContainersCp::Assets::Containers::Namespaces::Processor.new, customer_id, "namespaces"
  end
end
