class AwsAccount < ActiveRecord::Base
  AUTH_BY_ACCESS_KEY ||= 0
  AUTH_BY_ASSUMING_ROLE ||= 1
  ACCEPTED_CREDENTIALS ||= "accepted".freeze

  # Used by load_assets_cache. There is no is_active flag. All accounts are active at all times.
  scope :active, -> { all }

  belongs_to :customer
  has_many :aws_dynamo_db_tables
  has_and_belongs_to_many :aws_tags, join_table: :aws_accounts_aws_tags

  class << self
    def model_type_id
      ModelType::AWS_ACCOUNT
    end
  end

  def before_destroy
    raise ActiveRecord::ReadOnlyRecord
  end

  [:credentials_accepted?].each do |m|
    class_eval %(
      def #{m}
        raise 'Unsupported function. Use the credential service.'
      end
    ), __FILE__, __LINE__ - 4
  end

  [:iv, :auth_type,
    :access_key, :secret_key,
    :assume_role_arn, :assume_role_external_id,
    :username, :password].each do |m|
    class_eval %(
      def #{m}
        raise 'Access to this attribute is denied. Use the credential service.'
      end
    ), __FILE__, __LINE__ - 4
  end

  def classic_name
    "Aws Account #{owner_id}"
  end

  def crn
    if owner_id.blank?
      "crn:#{customer_id}:aws-account/unowned:#{id}"
    else
      "crn:#{customer_id}:aws-account/#{owner_id}"
    end
  end

  def oms_crn
    "crn::object-meta/com.cloudhealthtech.integrations.aws.AwsAccount"
  end
end
