# frozen_string_literal: true

class BaseTag < ActiveRecord::Base
  belongs_to :customer

  self.abstract_class = true

  class << self
    # MySQL ignores trailing spaces in string comparison
    # So let it fetch all that it thinks match because we want indexes to be used
    # and then we filter out the one we really asked for
    def find_by_customer_id_and_key_and_value_and_customer_tag(customer_id, key, value, customer_tag = false)
      where(customer_id: customer_id,
        key: key,
        value: value,
        customer_tag: customer_tag).find { |t| t.key == key && t.value == value && t.customer_tag == customer_tag }
    end

    def find_or_create_by_customer_id_and_key_and_value_and_customer_tag(customer_id, key, value, customer_tag = false)
      tag = find_by_customer_id_and_key_and_value_and_customer_tag customer_id, key, value, customer_tag
      return tag if tag
      new.tap do |t|
        t.customer_id = customer_id
        t.key = key
        t.value = value
        t.save!
      end
    end
  end
end
