# frozen_string_literal: true

require_relative "./asset_base"

class ContainersCluster < AssetBase
  include ::ContainersCp::Helpers::ModelDefaultScopes

  belongs_to :customer

  def classic_name
    "Containers Cluster"
  end

  def asset_name
    "cluster"
  end

  def service_name
    "kubernetes"
  end

  # determines if this cluster has a cloud account ID and internal account ID based on the provider
  def has_owner_account
    return false unless cloud_account_id && cloud_provider

    case cloud_provider.upcase
    when PROVIDER_AWS
      return false unless aws_account_id
    when PROVIDER_GCP
      return false unless gcp_compute_project_id
    when PROVIDER_AZURE
      return false unless azure_subscription_id
    else
      return false
    end
    true
  end
end
