require_relative "data_store"
require_relative "model_replication"

class Customer < ActiveRecord::Base
  include ::AwsScheduler::Helpers::ModelReplication

  belongs_to :country
  belongs_to :state

  has_many :users
  has_many :aws_accounts
  has_many :shard_assignments

  scope :assigned_to_current_shard, -> {
    joins(:shard_assignments)
      .where(
        shard_assignments: {
          data_store_id: ::ImportRegistry.resolve("cache.common_assets").data_store(::DataStore::MAIN).id,
          shard_id: ::Multidb.current_shard_id
        }
      )
  }

  # This is a special version of `active` that must match cht_models
  scope :active, -> { where(is_deleted: false, is_active: true) }

  after_create :create_proxies

  def has_feature?(bit)
    # Note: This works differently from the methods in cloudpercept and
    # cht_models! Use the bit number instead of the key (e.g. 33).
    return false if bit.nil? || feature_mask.blank?
    (feature_mask & 2**bit) > 0
  end

  def create_proxies
    CustomerDataProxies.create_lock_proxies(id)
  end

  def data_shard
    Application["shard_lookup"].main_shard(self)
  end

  def read_shard
    Application["shard_lookup"].read_shard(self)
  end
end
