#############
#  Classes here are pure proxies intended to help alleviate MySQL lock contention on the Customers primary table
# They're never to hold data.
# Instances are created via an after_create callback in Customer.
# Instances are destroyed by FK propagation when customer instances are deleted.
class CustomerDataEvents < ActiveRecord::Base
  belongs_to :customer
end

class CustomerDataConfig < ActiveRecord::Base
  belongs_to :customer
end

class CustomerDataMetrics < ActiveRecord::Base
  belongs_to :customer
end

class CustomerDataProxies
  def self.create_lock_proxies(customer_id)
    CustomerDataEvents.new.tap do |c|
      c.customer_id = customer_id
      c.save!
    end
    CustomerDataConfig.new.tap do |c|
      c.customer_id = customer_id
      c.save!
    end
    CustomerDataMetrics.new.tap do |c|
      c.customer_id = customer_id
      c.save!
    end
  end
end
