module AwsScheduler
  module Helpers
    module ModelReplication
      extend ::ActiveSupport::Concern

      included do
        # This is used when syncing a UDC master model. It is the preferred approach since it
        # won't try to write to all databases, especially when a shard could be in a bad state
        # Example: User is on db20, and db12 is currently having issues. We don't want to try to write to db12.
        def replicate_to_customer_data_shard
          data_shard = respond_to?(:customer) ? customer.data_shard : self.data_shard
          replicate_to_secondary_shards only_shard: data_shard
        end

        # You would generally only use this when syncing a non-customer specific model
        # Such as AwsRegion, which needs to be the same across all shards
        def replicate_to_secondary_shards(only_shard: nil)
          raise "Record in master must already exist" unless persisted?

          rec_ts = self.class.record_timestamps
          begin
            self.class.record_timestamps = false # Don't mess with :created_at or :updated_at

            ::Multidb.run_on_secondary_shards(only_shard) do |shard_name|
              next if shard_name.start_with? "read"
              next if !only_shard.nil? && only_shard.to_s != shard_name.to_s

              r = self.class.unscoped.where(id: id).first_or_initialize
              attributes.each_key do |attr|
                r.__send__("#{attr}=", __send__(attr))
              end
              r.save(validate: false)
            end
          ensure
            self.class.record_timestamps = rec_ts
          end
        end
      end
    end
  end
end
