# frozen_string_literal = true

module Engine
  class Runtime
    RUNTIME_OPTIONS = %w[
      development
      staging
      production
      test
    ].freeze

    # Values for DEPLOYMENT_PROVIDER environment variable set by helm
    DEPLOYMENT_PROVIDER_AWS = "aws"
    DEPLOYMENT_PROVIDER_GCP = "gcp"

    def env
      ENV["RACK_ENV"]
    end

    def sandbox?
      development? && ENV["SANDBOX"].to_i == 1
    end

    def provider
      ENV["DEPLOYMENT_PROVIDER"]
    end

    def provider_aws?
      # default to AWS for now
      return true unless ENV["DEPLOYMENT_PROVIDER"]
      ENV["DEPLOYMENT_PROVIDER"].downcase == DEPLOYMENT_PROVIDER_AWS
    end

    def provider_gcp?
      return false unless ENV["DEPLOYMENT_PROVIDER"]
      ENV["DEPLOYMENT_PROVIDER"].downcase == DEPLOYMENT_PROVIDER_GCP
    end

    def disable_s3?
      ENV["DISABLE_S3"] == "1"
    end

    RUNTIME_OPTIONS.each do |runtime|
      method_name = "#{runtime}?"
      define_method method_name do
        env == runtime
      end
    end
  end
end
