# frozen_string_literal: true

require "sidekiq_unique_jobs"

module ContainersCp::Workers
  class ProcessingAssetsWorker < ::CloudHealth::Processing::Workers::ProcessingAssetsWorker
    sidekiq_options queue: :processing_assets_containers,
      lock: :while_executing,
      on_conflict: :custom_reject_strategy,
      lock_args_method: :lock_args,
      lock_ttl: 2.hours.to_i,
      lock_info: true

    # Lock on customer ID, cluster, and asset type
    def self.lock_args(args)
      args_hash = args[1].first
      locking_args = nil
      # ensure we have the args we need, if not just return a unique key
      if args_hash["payload"]
        if args_hash["payload"]["kubernetes_cluster_id"] && args_hash["payload"]["asset"]
          locking_args = [args_hash["customer_id"], args_hash["payload"]["kubernetes_cluster_id"], args_hash["payload"]["asset"]]
        end
      end
      return locking_args unless locking_args.nil?
      locking_args = [args_hash["customer_id"], SecureRandom.uuid]
      Application["logger"].info("Returning random key for locking_args: #{locking_args}")
      locking_args
    end

    class << self
      # Custom version of Sidekiq's `perform_async`
      def perform_async(*args)
        Application["logger"].debug "ProcessingAssetsWorker.perform_async, args: #{args}"
        worker_class = self # Default to self.
        queue_prefix = "processing_assets_containers"
        # add this to args so it can be preserved if job rescheduled
        args[1].first["queue"] = queue_prefix.to_s
        args[1].first.stringify_keys!
        begin
          client_push("queue" => queue_prefix.to_s, "class" => worker_class, "args" => args)
        rescue ArgumentError => e
          Application["logger"].warn("Job arguments to ContainersCp::Workers::ProcessingAssetsWorker must be native JSON types. Arguments: #{args}")
        end
      end
    end
  end
end
